============
python-qqwry
============

Python Parse QQWry, based `qqwry.pdf`_

-------
Install
-------

::

  pip install pyqqwry


-----
Usage
-----

::

  from pyqqwry.qqwry import QQWry

  qq_wry = QQWry(path)
  print qq_wry("127.0.0.1")


.. _qqwry.pdf: https://drive.google.com/file/d/0B0EvSfZXS15seVVBRTlUOVlUb2M/view?usp=sharing
